.. django-composite-field documentation master file, created by
   sphinx-quickstart on Mon Jan  6 13:25:49 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

CompositeField for Django Models
================================

This is an implementation of a CompositeField for Django. Composite fields
can be used to group fields together and reuse their definitions.

.. toctree::
    :maxdepth: 2

    install.rst
    usage.rst
    examples.rst
    faq.rst
    changelog.rst
    license.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
